import { RevertableEvent } from "@skeldjs/events";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { HqHudEvent } from "./HqHudEvent";
import { Hostable } from "../../Hostable";
import { HqHudSystem } from "../../systems";
import { PlayerData } from "../../PlayerData";
/**
 * Emitted when a player opens a communications console on Mira HQ.
 */
export declare class HqHudConsoleOpenEvent<RoomType extends Hostable = Hostable> extends RevertableEvent implements RoomEvent, HqHudEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly hqhudsystem: HqHudSystem<RoomType>;
    readonly message: RepairSystemMessage | undefined;
    /**
     * The player that opened the console.
     */
    readonly player: PlayerData<RoomType>;
    /**
     * The ID of the console that was opened.
     */
    readonly consoleId: number;
    static eventName: "hqhud.consoles.open";
    eventName: "hqhud.consoles.open";
    private _alteredConsoleId;
    private _atleredPlayer;
    constructor(room: RoomType, hqhudsystem: HqHudSystem<RoomType>, message: RepairSystemMessage | undefined, 
    /**
     * The player that opened the console.
     */
    player: PlayerData<RoomType>, 
    /**
     * The ID of the console that was opened.
     */
    consoleId: number);
    /**
     * The alternate console ID that will be opened, if changed.
     */
    get alteredConsoleId(): number;
    /**
     * The alternate player that will open the console, if changed.
     */
    get alteredPlayer(): PlayerData<RoomType>;
    /**
     * Change the ID of the console that was opened.
     * @param consoleId The ID of the console to open.
     */
    setConsoleId(consoleId: number): void;
    /**
     * Change the player that opened the console.
     * @param player The player to open the console.
     */
    setPlayer(player: PlayerData<RoomType>): void;
}
